@@ -24,8 +24,14 @@ from dendropy.datamodel import basemodel
 from dendropy.datamodel import taxonmodel
 from dendropy.utility import deprecate
 from dendropy.utility import textprocessing
-if not (sys.version_info.major >= 3 and sys.version_info.minor >= 4):
+if sys.version_info.major >= 3 and sys.version_info.minor >= 4:
+    import pathlib
+    def _is_pathlib_path(x):
+        return isinstance(x, pathlib.PurePath)
+else:
     from dendropy.utility.filesys import pre_py34_open as open
+    def _is_pathlib_path(x):
+        return False
 
 ###############################################################################
 ## IOService
@@ -48,11 +54,13 @@ class IOService(object):
     def _get_attached_taxon_set(self):
         IOService.attached_taxon_set_deprecation_warning()
         return self.attached_taxon_namespace
-    def _set_attached_taxon_set(IOService, v):
+    def _set_attached_taxon_set(self, v):
         IOService.attached_taxon_set_deprecation_warning()
         self.attached_taxon_namespace = v
-    def _del_attached_taxon_set(IOService):
+    def _del_attached_taxon_set(self):
         IOService.attached_taxon_set_deprecation_warning()
+        del self.attached_taxon_namespace
+
     attached_taxon_set = property(_get_attached_taxon_set, _set_attached_taxon_set, _del_attached_taxon_set)
 
     def check_for_unused_keyword_arguments(self, kwargs_dict):
@@ -560,6 +568,9 @@ class DataYielder(IOService):
         if textprocessing.is_str_type(current_file):
             self._current_file = open(current_file, "r")
             self._current_file_name = current_file
+        elif _is_pathlib_path(current_file):
+            self._current_file = current_file.open()
+            self._current_file_name = current_file
         else:
             self._current_file = current_file
             try:
