@@ -41,7 +41,7 @@ class NexusTokenizer(Tokenizer):
         Tokenizer.__init__(self,
             src=src,
             uncaptured_delimiters=set(" \t\n\r"),
-            captured_delimiters=set("{}(),;:=\\\""),
+            captured_delimiters=set(r'{}(),;:=\"'),
             quote_chars=set("'"),
             escape_quote_by_doubling=True,
             escape_chars=set(""),
@@ -480,9 +480,9 @@ def escape_nexus_token(label, preserve_spaces=False, quote_underscores=True):
         return ""
     if not preserve_spaces \
             and "_" not in label \
-            and not re.search('[\(\)\[\]\{\}\\\/\,\;\:\=\*\'\"\`\+\-\<\>\0\t\n]', label):
+            and not re.search(r'''[\(\)\[\]\{\}\\/\\,\\;\\:\\=\\*'"\`\+\-\<\>\0\t\n]''', label):
         label = label.replace(' ', '_').replace('\t', '_')
-    elif re.search('[\(\)\[\]\{\}\\\/\,\;\:\=\*\'\"\`\+\-\<\>\0\t\n\r ]', label) \
+    elif re.search(r'''[\(\)\[\]\{\}\\/\,\;\:\=\*'"\`\+\-\<\>\0\t\n\r ]''', label) \
         or quote_underscores and "_" in label:
         s = label.split("'")
         if len(s) == 1:
