@@ -213,7 +213,8 @@ class Deserializable(object):
             New instance of object, constructed and populated from data given
             in source.
         """
-        with open(src, "r", newline=None) as fsrc:
+        open_args = ["r"] if sys.version_info >= (3, 3) else ["rU"]
+        with open(src, *open_args) as fsrc:
             return cls._parse_and_create_from_stream(stream=fsrc,
                     schema=schema,
                     **kwargs)
@@ -277,8 +278,8 @@ class Deserializable(object):
                     stream=ssrc,
                     schema=schema,
                     **kwargs)
-        except error.DataParseError:
-            sys.stderr.write(text)
+        except error.DataParseError as exc:
+            exc.url_text = text
             raise
     get_from_url = classmethod(get_from_url)
 
@@ -410,7 +411,8 @@ class MultiReadable(object):
                 - |CharacterMatrix|: number of sequences
                 - |DataSet|: ``tuple`` (number of taxon namespaces, number of tree lists, number of matrices)
         """
-        with open(src, "r", newline=None) as fsrc:
+        open_args = ["r"] if sys.version_info >= (3, 3) else ["rU"]
+        with open(src, *open_args) as fsrc:
             return self._parse_and_add_from_stream(stream=fsrc, schema=schema, **kwargs)
 
     def read_from_string(self, src, schema, **kwargs):
@@ -941,7 +943,7 @@ class Annotation(Annotable):
 
     def _get_namespace(self):
         if self._namespace is None:
-            self._namespace = "http://packages.python.org/DendroPy/"
+            self._namespace = "http://pypi.org/project/DendroPy/"
         return self._namespace
     def _set_namespace(self, prefix):
         self._namespace = prefix
@@ -1065,7 +1067,7 @@ class AnnotationSet(container.OrderedSet):
         if not name_is_prefixed:
             if name_prefix is None and namespace is None:
                 name_prefix = "dendropy"
-                namespace = "http://packages.python.org/DendroPy/"
+                namespace = "http://pypi.org/project/DendroPy/"
             elif name_prefix is None:
                 raise TypeError("Cannot specify 'name_prefix' for unqualified name without specifying 'namespace'")
             elif namespace is None:
@@ -1143,7 +1145,7 @@ class AnnotationSet(container.OrderedSet):
         if not name_is_prefixed:
             if name_prefix is None and namespace is None:
                 name_prefix = "dendropy"
-                namespace = "http://packages.python.org/DendroPy/"
+                namespace = "http://pypi.org/project/DendroPy/"
             elif name_prefix is None:
                 raise TypeError("Cannot specify 'name_prefix' for unqualified name without specifying 'namespace'")
             elif namespace is None:
@@ -1292,7 +1294,7 @@ class AnnotationSet(container.OrderedSet):
         # elif store_as.lower().startswith("bibtex-record"):
         #     if name_prefix is None and namespace is None:
         #         name_prefix = "dendropy"
-        #         namespace = "http://packages.python.org/DendroPy/"
+        #         namespace = "http://pypi.org/project/DendroPy/"
         #     self.add_new(
         #             name="bibtex",
         #             value=bt.as_compact_bibtex(),
@@ -1358,8 +1360,8 @@ class AnnotationSet(container.OrderedSet):
         that match based on *all* criteria specified in keyword arguments::
 
             >>> notes = tree.annotations.findall(name="color")
-            >>> notes = tree.annotations.findall(namespace="http://packages.python.org/DendroPy/")
-            >>> notes = tree.annotations.findall(namespace="http://packages.python.org/DendroPy/",
+            >>> notes = tree.annotations.findall(namespace="http://pypi.org/project/DendroPy/")
+            >>> notes = tree.annotations.findall(namespace="http://pypi.org/project/DendroPy/",
                                           name="color")
             >>> notes = tree.annotations.findall(name_prefix="dc")
             >>> notes = tree.annotations.findall(prefixed_name="dc:color")
@@ -1474,14 +1476,14 @@ class AnnotationSet(container.OrderedSet):
             >>> tree.annotations.drop(name="color")
 
         Remove all annotation objects with ``namespace`` ==
-        "http://packages.python.org/DendroPy/"::
+        "http://pypi.org/project/DendroPy/"::
 
-            >>> tree.annotations.drop(namespace="http://packages.python.org/DendroPy/")
+            >>> tree.annotations.drop(namespace="http://pypi.org/project/DendroPy/")
 
         Remove all annotation objects with ``namespace`` ==
-        "http://packages.python.org/DendroPy/" *and* ``name`` == "color"::
+        "http://pypi.org/project/DendroPy/" *and* ``name`` == "color"::
 
-            >>> tree.annotations.drop(namespace="http://packages.python.org/DendroPy/",
+            >>> tree.annotations.drop(namespace="http://pypi.org/project/DendroPy/",
                     name="color")
 
         Remove all annotation objects with ``name_prefix`` == "dc"::
