@@ -83,7 +83,12 @@ class SeqGen(object):
         return None
     get_model = staticmethod(get_model)
 
-    def __init__(self, strongly_unique_tempfiles=False):
+    def __init__(
+        self,
+        strongly_unique_tempfiles=False,
+        rng=None,
+        seq_len=None,
+    ):
         """
         Sets up all properties, which (generally) map directly to command
         parameters of Seq-Gen.
@@ -98,11 +103,11 @@ class SeqGen(object):
         # python object specific attributes
         self.seqgen_path = 'seq-gen'
         self.rng_seed = None
-        self._rng = None
+        self._rng = rng
 
         # following are passed to seq-gen in one form or another
         self.char_model = 'HKY'
-        self.seq_len = None
+        self.seq_len = seq_len
         self.num_partitions = None
         self.scale_branch_lens = None
         self.scale_tree_len = None
@@ -114,9 +119,9 @@ class SeqGen(object):
         self.ti_tv = 0.5 # = kappa of 1.0, i.e. JC
         self.general_rates = None
         self.ancestral_seq_idx = None
-        self.output_text_append = None
         self.write_ancestral_seqs = False
         self.write_site_rates = False
+        self.record_separator = "//"
 
     def _get_rng(self):
         if self._rng is None:
@@ -131,7 +136,11 @@ class SeqGen(object):
     def _set_kappa(self, kappa):
         self.ti_tv = kappa * 2
 
-    def _compose_arguments(self):
+    def _compose_arguments(
+        self,
+        output_format="nexus",
+        append_file=None,
+    ):
         """
         Composes and returns a list of strings that make up the arguments to a Seq-Gen
         call, based on the attribute values of the object.
@@ -170,20 +179,30 @@ class SeqGen(object):
                 args.append("-r%s" % (",".join([str(r) for r in self.general_rates])))
         if self.ancestral_seq_idx:
             args.append("-k%s" % self.ancestral_seq_idx)
-        if self.output_text_append:
-            args.append("-x'%s'" % self.output_text_append)
         if self.write_ancestral_seqs:
             args.append("-wa")
         if self.write_site_rates:
             args.append("-wr")
 
+        if output_format == "nexus":
+            args.append("-on")
+        elif output_format == "fasta":
+            args.append("-of")
+        elif output_format == "phylip":
+            args.append("-op")
+        elif output_format == "relaxed-phylip":
+            args.append("-or")
+        elif output_format:
+            raise ValueError(output_format)
+
+        if append_file:
+            args.append("-x%s" % append_file)
+
         # following are controlled directly by the wrapper
         # silent running
         args.append("-q")
         # we explicitly pass a random number seed on each call
         args.append("-z%s" % self.rng.randint(0, sys.maxsize))
-        # force nexus
-        args.append("-on")
         # force one dataset at a time
         args.append("-n1")
         return args
@@ -194,17 +213,90 @@ class SeqGen(object):
             dataset=None,
             taxon_namespace=None,
             input_sequences=None,
-            **kwargs):
-        args=self._compose_arguments()
+            tree_serialization_kwargs=None,
+            **kwargs
+    ):
+        stdout = self.generate_raw(
+            trees=trees,
+            taxon_namespace=taxon_namespace,
+            input_sequences=input_sequences,
+            tree_serialization_kwargs=tree_serialization_kwargs,
+            output_format="nexus",
+        )
+        if taxon_namespace is None:
+            taxon_namespace = trees.taxon_namespace
+        if dataset is None:
+            dataset = dendropy.DataSet(**kwargs)
+            if taxon_namespace is not None:
+                dataset.attach_taxon_namespace(taxon_namespace)
+        dataset.read(data=stdout, schema="nexus")
+        return dataset
+
+    def generate_dicts(
+            self,
+            **kwargs
+    ):
+        if "output_format" in kwargs:
+            raise TypeError("Cannot specify 'output_format' when requesting 'dict' result")
+        kwargs["output_format"] = "fasta"
+        if "append_file" in kwargs:
+            raise TypeError("Cannot specify 'append_file' when requesting 'dict' result")
+        # with self.get_tempfile() as textf:
+        with self.get_tempfile() as textf:
+            textf.write(self.record_separator)
+            textf.write("\n")
+            textf.flush()
+            kwargs["append_file"] = textf.name
+            raw_result = self.generate_raw(**kwargs)
+        data_ds = []
+        data_d = {}
+        label_data = None
+        sequence_data = []
+        for idx, line in enumerate(raw_result.split("\n")):
+            line = line.strip()
+            if not line:
+                continue
+            if line.startswith(">") or line == self.record_separator:
+                if label_data is not None:
+                    assert label_data not in data_d
+                    data_d[label_data] = "".join(sequence_data)
+                    sequence_data = []
+                else:
+                    assert not sequence_data
+                if line == self.record_separator:
+                    if data_d:
+                        data_ds.append(data_d)
+                        data_d = {}
+                        label_data = None
+                else:
+                    label_data = line[1:]
+            else:
+                sequence_data.append(line)
+        return data_ds
+
+    def generate_raw(
+            self,
+            trees,
+            taxon_namespace=None,
+            input_sequences=None,
+            tree_serialization_kwargs=None,
+            **kwargs
+    ):
+        args=self._compose_arguments(**kwargs)
         # with open("x.txt", "w") as inputf:
         with self.get_tempfile() as inputf:
             if input_sequences is not None:
                 input_sequences.write_to_stream(inputf, schema="phylip",)
                 inputf.write("{}\n".format(len(trees)))
-            trees.write_to_stream(inputf,
+            if tree_serialization_kwargs is None:
+                tree_serialization_kwargs = {}
+            trees.write_to_stream(
+                    inputf,
                     "newick",
                     suppress_rooting=True,
-                    suppress_internal_node_labels=True)
+                    suppress_internal_node_labels=True,
+                    **tree_serialization_kwargs
+            )
             inputf.flush()
             args.append(inputf.name)
             # print("seq-gen args: = %s" % " ".join(args))
@@ -212,14 +304,9 @@ class SeqGen(object):
             stdout, stderr = processio.communicate(run)
             if stderr or run.returncode != 0:
                 raise RuntimeError("Seq-gen error: %s" % stderr)
-            if taxon_namespace is None:
-                taxon_namespace = trees.taxon_namespace
-            if dataset is None:
-                dataset = dendropy.DataSet(**kwargs)
-                if taxon_namespace is not None:
-                    dataset.attach_taxon_namespace(taxon_namespace)
-            dataset.read(data=stdout, schema="nexus")
-            return dataset
+            return stdout
+
+
 
 
 
